#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""A setuptools-based setup module for coverage_audit.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""
# For matching the version string.
import re

# To use a consistent encoding
from codecs import open
from os import path

# Always prefer setuptools over distutils
from pathlib import Path

from setuptools import find_packages, setup

THIS_MODULE = "coverage_audit"
here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

requires = [
    "pytest>=5.4,<6.0",
]


def read(*parts):
    """
    Read _version.py.

    :param parts: paths to search for _version.py
    :return:
    """
    with open(path.join(here, *parts), "r") as fp:
        return fp.read()


def find_version() -> str:
    """
    What version are we now?

    :return: string representing current version of this app
    """
    version_file = read(Path.cwd() / "_version.py")
    if not version_file:
        raise RuntimeError("Unable to find version file.")

    version_match = re.search(r"^___version___ = ['\"]([^'\"]*)['\"]", version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError(f"Unable to find version string in {version_file}.")


setup(
    name="ssa-" + THIS_MODULE,
    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version=find_version(),
    description="Coverage Audit: the Workspaces Testing Coverage Audit",
    long_description=long_description,
    # Author details
    author="Science Support and Archive",
    author_email="ssa-announcements@nrao.edu",
    # Choose your license
    license="GPL",
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        "Development Status :: 4 - Beta",
        # Indicate who your project is intended for
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        # Pick your license as you wish (should match "license" above)
        "License :: OSI Approved :: GPL License",
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        "Programming Language :: Python :: 3.8",
    ],
    packages=find_packages(),
    entry_points={"console_scripts": ["coverage-audit = coverage_audit.coverage_audit:main"]},
)
